<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pa">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../src/core/ui/about.cpp" line="40"/>
        <source>About</source>
        <translation>ਇਸ ਬਾਰੇ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="41"/>
        <source>Thanks</source>
        <translation>ਧੰਨਵਾਦ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="42"/>
        <source>Help us</source>
        <translation>ਸਾਡੀ ਮਦਦ ਕਰੋ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="99"/>
        <source>is a crossplatform application for fast creating screenshots of your desktop.</source>
        <translation>ਤੁਹਾਡੇ ਡੈਸਕਟਾਪ ਦੇ ਤੇਜ਼ੀ ਨਾਲ ਸਕਰੀਨਸ਼ਾਟ ਲੈਣ ਲਈ ਅੰਤਰ-ਮੰਚ ਐਪਲੀਕੇਸ਼ਨ ਹੈ।</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="101"/>
        <source>It is a light and powerful application, written in Qt.</source>
        <translation>ਇਹ Qt ਵਿੱਚ ਲਿਖੀ ਹੋਈ ਹਲਕੀ ਅਤੇ ਮਜ਼ਬੂਤ ਐਪਲੀਕੇਸ਼ਨ ਹੈ।</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="33"/>
        <source>using Qt %1</source>
        <translation>Qt %1 ਵਰਤ ਕੇ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="104"/>
        <source>Website - &lt;a href=&quot;%1&quot;&gt;%1&lt;/a&gt;</source>
        <translation>ਵੈੱਬਸਾਈਟ - &lt;a href=&quot;%1&quot;&gt;%1&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="107"/>
        <source>Licensed under the &lt;a href=%1&gt;GPL v2&lt;/a&gt;</source>
        <translation>ਇਸ ਨੂੰ &lt;a href=%1&gt;GPL v2&lt;/a&gt; ਅਧੀਨ ਲਸੰਸ ਦਿੱਤਾ ਹੈ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="111"/>
        <source>Copyright &amp;copy; 2009-2013, Artem &apos;DOOMer&apos; Galichkin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="113"/>
        <source>Copyright &amp;copy; 2013-2025, LXQt team</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="120"/>
        <source>You can join us and help us if you want. This is an invitation if you like this application.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="123"/>
        <source>What you can do?</source>
        <translation>ਤੁਸੀਂ ਕੀ ਕਰ ਸਕਦੇ ਹੋ?</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="126"/>
        <source>Translate ScreenGrab to other languages</source>
        <translation>ਸਕਰੀਨਗਰੈਬ ਨੂੰ ਹੋਰ ਭਾਸ਼ਾਵਾਂ ਵਿੱਚ ਅਨੁਵਾਦ ਕਰੋ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="127"/>
        <source>Make suggestions for next releases</source>
        <translation>ਅਗਲੇ ਰੀਲਿਜ਼ ਲਈ ਸੁਝਾਅ ਦਿਓ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="128"/>
        <source>Report bugs and issues</source>
        <translation>ਬੱਗ ਤੇ ਮਸਲਿਆਂ ਬਾਰੇ ਰਿਪੋਰਟ ਦਿਓ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="131"/>
        <source>Bug tracker</source>
        <translation>ਬੱਗ ਟਰੈਕਰ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="142"/>
        <source>Special thanks to:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="144"/>
        <source>for creating ScreenGrab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="145"/>
        <source>for supporting wlr screencopy protocol</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="190"/>
        <source>Directory %1 does not exist. Do you want to create it?</source>
        <translation>ਡਾਇਰੈਕਟਰੀ %1 ਮੌਜੂਦ ਨਹੀਂ ਹੈ। ਕੀ ਤੁਸੀਂ ਇਸ ਨੂੰ ਬਣਾਉਣਾ ਚਾਹੁੰਦੇ ਹੋ?</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="191"/>
        <location filename="../src/core/ui/configwidget.cpp" line="280"/>
        <source>Warning</source>
        <translation>ਸਾਵਧਾਨ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="268"/>
        <source>Select directory</source>
        <translation>ਡਾਇਰੈਕਟਰੀ ਚੁਣੋ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="279"/>
        <source>Do you want to reset the settings to the defaults?</source>
        <translation>ਕੀ ਤੁਸੀਂ ਮੂਲ ਲਈ ਸੈਟਿੰਗਾਂ ਨੂੰ ਮੁੜ-ਸੈੱਟ ਕਰਨਾ ਚਾਹੁੰਦੇ ਹੋ?</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="313"/>
        <source>Example: </source>
        <translation>ਮਿਸਾਲ: </translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="354"/>
        <source>This key is already used in ScreenGrab! Please select another.</source>
        <translation>ਇਹ ਸਵਿੱਚ ਪਹਿਲਾਂ ਹੀ ਸਕਰੀਨਗਰੈਬ ਵਲੋਂ ਵਰਤੀ ਜਾ ਰਹੀ ਹੈ। ਹੋਰ ਚੁਣੋ।</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="372"/>
        <source>This key is not supported on your system!</source>
        <translation>ਇਹ ਸਵਿੱਚ ਤੁਹਾਡੇ ਸਿਸਟਮ ਵਲੋਂ ਸਹਾਇਕ ਨਹੀਂ ਹੈ!</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="392"/>
        <source>Error</source>
        <translation>ਗਲਤੀ</translation>
    </message>
</context>
<context>
    <name>Core</name>
    <message>
        <location filename="../src/core/core.cpp" line="66"/>
        <source>is a crossplatform application for fast creating screenshots of your desktop.</source>
        <translation type="unfinished">ਤੁਹਾਡੇ ਡੈਸਕਟਾਪ ਦੇ ਤੇਜ਼ੀ ਨਾਲ ਸਕਰੀਨਸ਼ਾਟ ਲੈਣ ਲਈ ਅੰਤਰ-ਮੰਚ ਐਪਲੀਕੇਸ਼ਨ ਹੈ।</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="70"/>
        <source>Take a fullscreen screenshot</source>
        <translation>ਪੂਰੀ ਸਕਰੀਨ ਦਾ ਸਕਰੀਨਸ਼ਾਟ ਲਵੋ</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="74"/>
        <source>Take a screenshot of the active window</source>
        <translation>ਸਰਗਰਮ ਵਿੰਡੋ ਦਾ ਸਕਰੀਨਸ਼ਾਟ ਲਵੋ</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="78"/>
        <source>Take a screenshot of a selection of the screen</source>
        <translation>ਸਕਰੀਨ ਦੇ ਚੁਣੇ ਹਿੱਸੇ ਦਾ ਸਕਰੀਨਸ਼ਾਟ ਲਵੋ</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="82"/>
        <source>Run the application with a hidden main window</source>
        <translation>ਲੁਕਵੀ ਮੁੱਖ ਵਿੰਡੋ ਨਾਲ ਐਪਲੀਕੇਸ਼ਨ ਨੂੰ ਚਲਾਓ</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="85"/>
        <source>Save screenshot and exit, without showing window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="575"/>
        <source>Saved</source>
        <translation>ਸੰਭਾਲਿਆ</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="575"/>
        <source>Saved to </source>
        <translation>ਇੱਥੇ ਸੰਭਾਲਿਆ </translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="597"/>
        <source>Name of saved file is copied to the clipboard</source>
        <translation>ਸੰਭਾਲੀ ਹੋਈ ਫਾਇਲ ਦਾ ਨਾਂ ਕਲਿੱਪਬੋਰਡ ਵਿੱਚ ਕਾਪੀ ਕੀਤਾ ਹੈ</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="603"/>
        <source>Path to saved file is copied to the clipboard</source>
        <translation>ਸੰਭਾਲੀ ਹੋਈ ਫਾਇਲ ਦਾ ਪਾਥ ਕਲਿੱਪਬੋਰਡ ਵਿੱਚ ਕਾਪੀ ਕੀਤਾ ਹੈ</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="626"/>
        <source>Copied</source>
        <translation>ਕਾਪੀ ਕੀਤਾ</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="626"/>
        <source>Screenshot is copied to clipboard</source>
        <translation>ਸਕਰੀਨਸ਼ਾਟ ਨੂੰ ਕਲਿੱਪਬੋਰਡ ਵਿੱਚ ਕਾਪੀ ਕੀਤਾ ਹੈ</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="14"/>
        <source>ScreenGrab</source>
        <translation>ਸਕਰੀਨਗਰੈਬ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="73"/>
        <source>Screen:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="105"/>
        <source>Type:</source>
        <translation>ਕਿਸਮ:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="115"/>
        <source>Type of screenshot</source>
        <translation>ਸਕਰੀਨਸ਼ਾਟ ਦੀ ਕਿਸਮ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="122"/>
        <source>Full screen</source>
        <translation>ਪੂਰੀ ਸਕਰੀਨ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="127"/>
        <source>Window</source>
        <translation>ਵਿੰਡੋ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="132"/>
        <source>Screen area</source>
        <translation>ਸਕਰੀਨ ਦਾ ਹਿੱਸਾ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="137"/>
        <source>Last selected area</source>
        <translation>ਆਖਰੀ ਚੁਣਿਆ ਹਿੱਸਾ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="167"/>
        <source>Delay:</source>
        <translation>ਦੇਰੀ:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="180"/>
        <source>Delay in seconds before taking screenshot</source>
        <translation>ਸਕਰੀਨਸ਼ਾਟ ਲੈਣ ਤੋਂ ਪਹਿਲਾਂ ਸਕਿੰਟਾਂ ਵਿੱਚ ਦੇਰੀ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="183"/>
        <source>None</source>
        <translation>ਕੋਈ ਨਹੀਂ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="186"/>
        <source> sec</source>
        <translation> ਸਕਿੰਟ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="245"/>
        <source>Zoom area around mouse</source>
        <translation>ਮਾਊਸ ਦੇ ਦੁਆਲੇ ਖੇਤਰ ਨੂੰ ਜ਼ੂਮ ਕਰੋ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="252"/>
        <source>No window decoration</source>
        <translation>ਕੋਈ ਵਿੰਡੋ ਸਜਾਵਟ ਨਹੀਂ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="259"/>
        <source>Include mouse pointer</source>
        <translation>ਮਾਊਸ ਪੁਆਇੰਟਰ ਸਮੇਤ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="291"/>
        <source>toolBar</source>
        <translation>ਟੂਲਬਾਰ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="44"/>
        <source>New</source>
        <translation>ਨਵਾਂ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="45"/>
        <source>Save</source>
        <translation>ਸੰਭਾਲੋ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="46"/>
        <source>Copy</source>
        <translation>ਕਾਪੀ ਕਰੋ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="47"/>
        <source>Options</source>
        <translation>ਚੋਣਾਂ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="48"/>
        <source>About</source>
        <translation>ਇਸ ਬਾਰੇ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="49"/>
        <source>Quit</source>
        <translation>ਬਾਹਰ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="358"/>
        <source>Screenshot </source>
        <translation>ਸਕਰੀਨਸ਼ਾਟ </translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="362"/>
        <source>Double click to open screenshot in external default image viewer</source>
        <translation>ਸਕਰੀਨਸ਼ਾਟ ਨੂੰ ਹੋਰ ਮੂਲ ਚਿੱਤਰ ਦਰਸ਼ਕ ਨਾਲ ਖੋਲ੍ਹਣ ਲਈ ਦੋ ਵਾਰ ਕਲਿੱਕ ਕਰੋ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="371"/>
        <location filename="../src/core/ui/mainwindow.cpp" line="540"/>
        <source>Hide</source>
        <translation>ਓਹਲੇ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="547"/>
        <source>Show</source>
        <translation>ਵੇਖਾਓ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="616"/>
        <source>%1 Files</source>
        <translation>%1 ਫਾਇਲਾਂ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="638"/>
        <source>Save As...</source>
        <translation>...ਵਜੋਂ ਸੰਭਾਲੋ</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../src/core/regionselect.cpp" line="148"/>
        <source>Click and drag to draw a rectangle,
double click or press Enter
to take a screenshot,
or press Escape to cancel.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/regionselect.cpp" line="245"/>
        <source>Click and drag to draw a rectangle,
right click to fit to edges,
double click or press Enter
to take a screenshot.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/regionselect.cpp" line="305"/>
        <source>%1 x %2 pixels </source>
        <translation>%1 x %2 ਪਿਕਸਲ </translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/modules/extedit/moduleextedit.cpp" line="35"/>
        <source>External edit</source>
        <translation>ਬਾਹਰੀ ਸੋਧ</translation>
    </message>
    <message>
        <location filename="../src/modules/extedit/moduleextedit.cpp" line="46"/>
        <source>Edit in...</source>
        <translation>...ਵਿੱਚ ਸੋਧੋ</translation>
    </message>
</context>
<context>
    <name>aboutWidget</name>
    <message>
        <location filename="../src/core/ui/aboutwidget.ui" line="118"/>
        <source>About Qt</source>
        <translation>Qt ਬਾਰੇ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/aboutwidget.ui" line="144"/>
        <source>Close</source>
        <translation>ਬੰਦ ਕਰੋ</translation>
    </message>
</context>
<context>
    <name>configwidget</name>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="26"/>
        <location filename="../src/core/ui/configwidget.ui" line="536"/>
        <source>Options</source>
        <translation>ਚੋਣਾਂ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="35"/>
        <source>Main</source>
        <translation>ਮੁੱਖ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="40"/>
        <source>Advanced</source>
        <translation>ਤਕਨੀਕੀ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="45"/>
        <source>System tray</source>
        <translation>ਸਿਸਟਮ ਟਰੇ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="50"/>
        <source>Shortcuts</source>
        <translation>ਸ਼ਾਰਟਕੱਟ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="74"/>
        <source>Default save directory</source>
        <translation>ਸੰਭਾਲਣ ਲਈ ਮੂਲ ਡਾਇਰੈਕਟਰੀ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="80"/>
        <source>Path to default selection dir for saving</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="93"/>
        <source>Browse filesystem</source>
        <translation>ਫਾਇਲ-ਸਿਸਟਮ ਦੀ ਝਲਕ ਵੇਖੋ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="96"/>
        <source>Browse</source>
        <translation>ਝਲਕ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="106"/>
        <source>Default file</source>
        <translation>ਮੂਲ ਫਾਇਲ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="119"/>
        <source>Name:</source>
        <translation>ਨਾਂ:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="126"/>
        <source>Default filename</source>
        <translation>ਮੂਲ ਫਾਇਲ-ਨਾਂ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="137"/>
        <source>Format</source>
        <translation>ਫਾਰਮੈਟ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="150"/>
        <source>Default saving image format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="169"/>
        <source>Copy file name to the clipboard when saving</source>
        <translation>ਸੰਭਾਲਣ ਸਮੇਂ ਫਾਇਲ ਦੇ ਨਾਂ ਨੂੰ ਕਲਿੱਪਬੋਰਡ ਵਿੱਚ ਕਾਪੀ ਕਰੋ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="183"/>
        <source>Do not copy</source>
        <translation>ਕਾਪੀ ਨਾ ਕਰੋ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="188"/>
        <source>Copy file name only</source>
        <translation>ਸਿਰਫ਼ ਫਾਇਥ ਦੇ ਨਾਂ ਨੂੰ ਕਾਪੀ ਕਰੋ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="193"/>
        <source>Copy full file path</source>
        <translation>ਪੂਰੇ ਪਾਥ ਨੂੰ ਕਾਪੀ ਕਰੋ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="203"/>
        <source>Image quality</source>
        <translation>ਚਿੱਤਰ ਦੀ ਕੁਆਲਟੀ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="209"/>
        <source>Image quality (1 - small file, 100 - high quality)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="274"/>
        <source>Inserting current date time into saved filename</source>
        <translation>ਸੰਭਾਲੀ ਫਾਇਲ ਦੇ ਨਾਂ ਵਿੱਚ ਮੌਜੂਦ ਤਾਰੀਖ ਤੇ ਸਮਾਂ ਜਾਣਕਾਰੀ ਪਾਓ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="277"/>
        <source>Insert current date and time in file name</source>
        <translation>ਫਾਇਲ ਦੇ ਨਾਂ ਵਿੱਚ ਮੌਜੂਦਾ ਤਾਰੀਖ ਤੇ ਸਮੇਂ ਨੂੰ ਪਾਓ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="286"/>
        <source>Template: </source>
        <translation>ਟੈਂਪਲੇਟ: </translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="311"/>
        <source>Example: </source>
        <translation>ਮਿਸਾਲ: </translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="321"/>
        <source>Automatically saving screenshots in grabbing process</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="324"/>
        <source>Autosave screenshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="336"/>
        <source>Save first screenshot</source>
        <translation>ਪਹਿਲਾਂ ਸਕਰੀਨਸ਼ਾਟ ਸੰਭਾਲੋ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="345"/>
        <source>Allow run multiplies copy of ScreenGrab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="348"/>
        <source>Allow multiple instances of ScreenGrab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="355"/>
        <source>Open in external viewer on double click</source>
        <translation>ਦੋ ਵਾਰ ਕਲਿੱਕ ਕਰਨ ਨਾਲ ਬਾਹਰੀ ਦਰਸ਼ਕ ਵਿੱਚ ਖੋਲ੍ਹੋ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="358"/>
        <source>Enable external viewer</source>
        <translation>ਬਾਹਰੀ ਦਰਸ਼ਕ ਸਮਰੱਥ ਕਰੋ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="365"/>
        <source>If this is unchecked, the selected area
might become larger to fit to outer edges</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="369"/>
        <source>Fit to edges inside selected area by right clicking</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="376"/>
        <source>With multiple screens</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="379"/>
        <source>Remember last selected screen in next session</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="386"/>
        <source>Notify on saving and copying</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="395"/>
        <source>Duration:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="462"/>
        <source>Show ScreenGrab in the system tray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="402"/>
        <source> sec</source>
        <translation> ਸਕਿੰਟ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="469"/>
        <source>Minimize to tray on click close button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="472"/>
        <source>Minimize to tray when closing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="511"/>
        <source>Action</source>
        <translation>ਕਾਰਵਾਈ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="516"/>
        <source>Shortcut</source>
        <translation>ਸ਼ਾਰਟਕੱਟ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="521"/>
        <source>New screen</source>
        <translation>ਨਵੀਂ ਸਕਰੀਨ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="526"/>
        <source>Save screen</source>
        <translation>ਸਕਰੀਨ ਨੂੰ ਸੰਭਾਲੋ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="531"/>
        <source>Copy screen</source>
        <translation>ਸਕਰੀਨ ਨੂੰ ਕਾਪੀ ਕਰੋ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="541"/>
        <source>Quit</source>
        <translation>ਬਾਹਰ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="551"/>
        <source>Selected shortcut:</source>
        <translation>ਸ਼ਾਰਟਕੱਟ ਚੁਣੋ:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="558"/>
        <source>Not defined</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
